@@ -5,8 +5,7 @@
   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef CALENDARSUPPORT_CATEGORYCONFIG_H
-#define CALENDARSUPPORT_CATEGORYCONFIG_H
+#pragma once
 
 #include "calendarsupport_export.h"
 
@@ -16,13 +15,14 @@
 class KCoreConfigSkeleton;
 class QColor;
 
-namespace CalendarSupport {
+namespace CalendarSupport
+{
 class CALENDARSUPPORT_EXPORT CategoryConfig : public QObject
 {
     Q_OBJECT
 public:
     explicit CategoryConfig(KCoreConfigSkeleton *cfg, QObject *parent = nullptr);
-    ~CategoryConfig();
+    ~CategoryConfig() override;
     Q_REQUIRED_RESULT QStringList customCategories() const;
     void setCustomCategories(const QStringList &categories);
 
@@ -32,6 +32,7 @@ public:
     void writeConfig();
 
     static const QString categorySeparator;
+
 private:
     Q_DISABLE_COPY(CategoryConfig)
     class Private;
@@ -39,4 +40,3 @@ private:
 };
 }
 
-#endif
